@@ -1,6 +1,10 @@
 #!/bin/sh
 # a scripts to get the cvs source up and running
-# $Revision: 92 $
+# $Revision: 722 $
+
+#bail out on error
+set -e
+
 aclocal
 autoheader
 automake --add-missing
